@import "../components/bootstrap/less/variables.less";

@logo-height: 28px;

#jupyterhub-logo {
  @media (max-width: @grid-float-breakpoint) {
    // same length as the navbar-toggle element, displayed on responsive mode
    margin-left: 15px;
  }
  .jpy-logo {
    height: @logo-height;
    margin-top: (@navbar-height - @logo-height) / 2;
  }
}

.navbar-right {
  li {
    span {
      // same as .nav > li > a from bootstrap, but applied to the span[id="login_widget"]
      // or any other span that matches .nav > li > span, but only in responsive mode
      @media (max-width: @grid-float-breakpoint) {
        position: relative;
        display: block;
        padding: 10px 15px;
      }
    }
  }
}

#header {
  border-bottom: 1px solid #e7e7e7;
}

.hidden {
  display: none;
}

#progress-log {
  margin-top: 8px;
}

.progress-log-event {
  border-top: 1px solid #e7e7e7;
  padding: 8px;
}

// hover-highlight on log events?
// .progress-log-event:hover {
//   background: rgba(66, 165, 245, 0.2);
// }

.feedback {
  &-container {
    margin-top: 16px;
  }

  &-widget {
    padding: 5px 0px 0px 6px;
    i {
      font-size: 2em;
      color: lightgrey;
    }
  }
}
